from tsjPython import tsjCommonFunc


a = 1
tsjCommonFunc.passPrint(a)
tsjCommonFunc.valuePrint(a)
